aboutsummaryrefslogtreecommitdiff
path: root/tests/includes/mach/mig_support.h
diff options
context:
space:
mode:
Diffstat (limited to 'tests/includes/mach/mig_support.h')
-rw-r--r--tests/includes/mach/mig_support.h18
1 files changed, 17 insertions, 1 deletions
diff --git a/tests/includes/mach/mig_support.h b/tests/includes/mach/mig_support.h
index e725a63..78c1f03 100644
--- a/tests/includes/mach/mig_support.h
+++ b/tests/includes/mach/mig_support.h
@@ -1 +1,17 @@
-/* This file allows the testsuite to compile under Linux. */
+/* This file allows the testsuite to compile under Linux
+ * which doesn't have mach/mig_support.h */
+
+#ifndef _MACH_MIG_SUPPORT_H
+
+#define _MACH_MIG_SUPPORT_H 1
+
+#include <mach/std_types.h>
+#include <string.h>
+
+mach_port_t mig_get_reply_port (void);
+void mig_dealloc_reply_port (mach_port_t);
+void mig_put_reply_port (mach_port_t);
+void mig_allocate (vm_address_t *__addr_p, vm_size_t __size);
+void mig_deallocate (vm_address_t __addr, vm_size_t __size);
+
+#endif